@@ -15,7 +15,7 @@
 #include <fcitx-utils/key.h>
 #include <fcitx-utils/keysym.h>
 #include <fcitx-utils/misc.h>
-#include <fcitx-utils/standardpath.h>
+#include <fcitx-utils/standardpaths.h>
 #include <fcitx-utils/textformatflags.h>
 #include <fcitx-utils/utf8.h>
 #include <fcitx/action.h>
@@ -98,12 +98,12 @@ std::string subUTF8String(const std::string &str, int p1, int p2) {
 }
 
 HanjaTable *loadTable() {
-    const auto &sp = fcitx::StandardPath::global();
-    std::string hanjaTxt =
-        sp.locate(fcitx::StandardPath::Type::Data, "libhangul/hanja/hanja.txt");
+    const auto &sp = fcitx::StandardPaths::global();
+    auto hanjaTxt =
+        sp.locate(fcitx::StandardPathsType::Data, "libhangul/hanja/hanja.txt");
     HanjaTable *table = nullptr;
     if (!hanjaTxt.empty()) {
-        table = hanja_table_load(hanjaTxt.c_str());
+        table = hanja_table_load(hanjaTxt.string().c_str());
     }
     return table ? table : hanja_table_load(nullptr);
 }
@@ -134,11 +134,24 @@ public:
     void configure() {
         context_.reset(hangul_ic_new(
             keyboardId[static_cast<int>(*engine_->config().keyboard)]));
+#if defined(FCITX_HANGUL_VERSION_0_2)
+        hangul_ic_set_option(context_.get(), HANGUL_IC_OPTION_AUTO_REORDER,
+                             *engine_->config().autoReorder);
+        hangul_ic_set_option(context_.get(),
+                             HANGUL_IC_OPTION_COMBI_ON_DOUBLE_STROKE,
+                             *engine_->config().combiOnDoubleStroke);
+        hangul_ic_set_option(context_.get(),
+                             HANGUL_IC_OPTION_NON_CHOSEONG_COMBI,
+                             *engine_->config().nonChoseongCombi);
+#else
         hangul_ic_connect_callback(
             context_.get(), "transition",
             reinterpret_cast<void *>(&HangulState::onTransitionCallback), this);
+#endif
     }
 
+#if !defined(FCITX_HANGUL_VERSION_0_2)
+
     static bool onTransitionCallback(HangulInputContext * /*unused*/, ucschar c,
                                      const ucschar * /*unused*/, void *data) {
         auto *that = static_cast<HangulState *>(data);
@@ -163,6 +176,7 @@ public:
 
         return true;
     }
+#endif
 
     void updateLookupTable(bool checkSurrounding) {
         std::string hanjaKey;
@@ -614,10 +628,10 @@ HangulEngine::HangulEngine(Instance *instance)
         throw std::runtime_error("Failed to load hanja table.");
     }
 
-    auto file = StandardPath::global().locate(StandardPath::Type::PkgData,
-                                              "hangul/symbol.txt");
+    auto file = StandardPaths::global().locate(StandardPathsType::PkgData,
+                                               "hangul/symbol.txt");
     if (!file.empty()) {
-        symbolTable_.reset(hanja_table_load(file.data()));
+        symbolTable_.reset(hanja_table_load(file.string().c_str()));
     }
 
     reloadConfig();
